
## CATO-CLI - query.site.cloudInterconnectConnectionConnectivity:
[Click here](https://api.catonetworks.com/documentation/#query-cloudInterconnectConnectionConnectivity) for documentation on this operation.

### Usage for query.site.cloudInterconnectConnectionConnectivity:

`catocli query site cloudInterconnectConnectionConnectivity -h`

`catocli query site cloudInterconnectConnectionConnectivity <json>`

`catocli query site cloudInterconnectConnectionConnectivity "$(cat < cloudInterconnectConnectionConnectivity.json)"`

`catocli query site cloudInterconnectConnectionConnectivity '{"cloudInterconnectConnectionConnectivityInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for query.site.cloudInterconnectConnectionConnectivity ####
`accountId` [ID] - (required) N/A 
`cloudInterconnectConnectionConnectivityInput` [CloudInterconnectConnectionConnectivityInput] - (required) N/A 
